@@ -2,6 +2,7 @@ from cgitb import text
 import logging
 import schedule
 import datetime
+import time
 
 from pexpect import TIMEOUT
 from telegram import Update
@@ -139,7 +140,7 @@ async def temperature(update: Update, context: ContextTypes.DEFAULT_TYPE):
         data = c.fetchone()
         # Calculate the time since the last update
         time_since_update = datetime.datetime.now() - datetime.datetime.strptime(data[0], '%Y-%m-%d %H:%M:%S')
-        text += f"{data[1]}: {data[3]} °C  ({ time_since_update.min } minuuttia sitten) \n" 
+        text += f"{data[1]}: {data[3]} °C  ({ time_since_update / datetime.timedelta(minutes=1) } minuuttia sitten) \n" 
     
     await context.bot.send_message(chat_id=update.effective_chat.id, text=text)
 
@@ -276,7 +277,13 @@ def main():
     # Update ruuvi data every 5 minutes
     schedule.every(5).minutes.do(get_ruuvi_data)
 
-    application.run_polling()
+    application.start_polling()
+
+    while True:
+        schedule.run_pending()
+        time.sleep(1)
+
+    application.stop()
 
 
 if __name__ == "__main__":
